package org.eco.als.listener;

import cn.hutool.core.bean.BeanUtil;
import cn.hutool.core.util.ObjectUtil;
import com.alibaba.excel.context.AnalysisContext;
import com.alibaba.excel.event.AnalysisEventListener;
import lombok.extern.slf4j.Slf4j;
import org.eco.als.domain.bo.AircraftBo;
import org.eco.als.domain.vo.AircraftImportVo;
import org.eco.als.domain.vo.AircraftVo;
import org.eco.als.service.IAircraftService;
import org.eco.common.core.core.domain.model.LoginUser;
import org.eco.common.core.utils.SpringUtils;
import org.eco.common.core.utils.ValidatorUtils;
import org.eco.common.excel.core.ExcelListener;
import org.eco.common.excel.core.ExcelResult;
import org.eco.common.excel.entity.ExcelResultRes;

import java.util.List;

/**
 * 机型机号自定义导入
 *
 * @author wgk
 */
@Slf4j
public class AircraftImportListener extends AnalysisEventListener<AircraftImportVo> implements ExcelListener<AircraftImportVo> {
    private final IAircraftService aircraftService;

    private final Boolean isUpdateSupport;
    private final LoginUser loginUser;
    private final StringBuilder successMsg = new StringBuilder();
    private final StringBuilder failureMsg = new StringBuilder();
    private int successNum = 0;
    private int failureNum = 0;

    public AircraftImportListener(Boolean isUpdateSupport, LoginUser loginUser) {
        this.aircraftService = SpringUtils.getBean(IAircraftService.class);
        this.isUpdateSupport = isUpdateSupport;
        this.loginUser = loginUser;
    }

    @Override
    public void invoke(AircraftImportVo aircraftVo, AnalysisContext context) {
        try {

            AircraftBo aircraftBo = BeanUtil.toBean(aircraftVo, AircraftBo.class);

            //TODO:根据某个字段，查询数据库表中是否存在记录，不存在就新增，存在就更新
            AircraftVo aircraftVo1 = null;

            aircraftVo1 = aircraftService.selectById(aircraftVo.getId());
            if (ObjectUtil.isNull(aircraftVo1)) {
                //不存在就新增
                aircraftBo.setVersion(0);
                ValidatorUtils.validate(aircraftBo);
                boolean inserted = aircraftService.insertWithPk(aircraftBo);//树表需要前台传来主键值

                if (inserted) {
                    successNum++;
                    successMsg.append("<br/>").append(successNum).append("、机型机号 记录导入成功");
                    return;
                } else {
                    failureNum++;
                    failureMsg.append("<br/>").append(failureNum).append("、机型机号 记录导入失败");
                    return;
                }
            } else if (isUpdateSupport) {
                //存在就更新
                aircraftBo.setId(aircraftVo1.getId());//主键
                aircraftBo.setVersion(aircraftVo1.getVersion());
                boolean updated = aircraftService.update(aircraftBo);
                if (updated) {
                    successNum++;
                    successMsg.append("<br/>").append(successNum).append("、机型机号 记录更新成功");
                    return;
                } else {
                    failureNum++;
                    failureMsg.append("<br/>").append(failureNum).append("、机型机号 记录更新失败");
                    return;
                }
            }
        } catch (Exception e) {
            failureNum++;
            String msg = "<br/>" + failureNum + "、机型机号 记录导入失败：" ;
            failureMsg.append(msg).append(e.getMessage());
            log.error(msg, e);
        }
    }

    @Override
    public void doAfterAllAnalysed(AnalysisContext context) {
        log.info("解析完成");
    }

    @Override
    public ExcelResult<AircraftImportVo> getExcelResult() {
        return new ExcelResult<>() {

            @Override
            public ExcelResultRes getAnalysis() {
                if (failureNum > 0 && successNum == 0) {
                    failureMsg.insert(0, "很抱歉，导入失败！共 " + failureNum + " 条数据没有成功导入，错误如下：");
                    return ExcelResultRes.builder().logInfo(failureMsg.toString()).status("0").build();
                } else if (failureNum > 0 && successNum > 0) {
                    failureMsg.insert(0, "很抱歉，部分导入失败！共 " + failureNum + " 条数据没有成功导入，错误如下：");
                    return ExcelResultRes.builder().logInfo(failureMsg.toString()).status("2").build();
                } else {
                    successMsg.insert(0, "恭喜您，数据已全部导入成功！共 " + successNum + " 条，数据如下：");
                    return ExcelResultRes.builder().logInfo(successMsg.toString()).status("1").build();
                }
            }

            @Override
            public List<AircraftImportVo> getList() {
                return null;
            }

            @Override
            public List<String> getErrorList() {
                return null;
            }
        };
    }
}
