package org.eco.als.service;

import org.eco.als.domain.Aircraft;
import org.eco.als.domain.bo.AircraftBo;
import org.eco.als.domain.vo.AircraftVo;
import org.eco.common.core.core.domain.model.LoginUser;
import org.eco.common.orm.core.service.IBaseService;
import org.springframework.scheduling.annotation.Async;
import org.springframework.web.multipart.MultipartFile;

import java.util.List;

/**
 * 机型机号Service接口
 *
 * @author wgk
 * @date 2024-07-18
 */
public interface IAircraftService extends IBaseService<Aircraft> {
    /**
     * 查询机型机号
     *
     * @param id 机型机号主键
     * @return 机型机号
     */
    AircraftVo selectById(Long id);

    /**
     * 查询机型机号列表
     *
     * @param aircraftBo 机型机号Bo
     * @return 机型机号集合
     */
    List<AircraftVo> selectList(AircraftBo aircraftBo);


    /**
     * 新增机型机号
     *
     * @param aircraftBo 机型机号Bo
     * @return 结果:true 操作成功，false 操作失败
     */
    boolean insert(AircraftBo aircraftBo);

    /**
     * 新增机型机号，前台提供主键值，一般用于导入的场合
     *
     * @param aircraftBo 机型机号Bo
     * @return 结果:true 操作成功，false 操作失败
     */
    boolean insertWithPk(AircraftBo aircraftBo);

    /**
     * 修改机型机号
     *
     * @param aircraftBo 机型机号Bo
     * @return 结果:true 更新成功，false 更新失败
     */
    boolean update(AircraftBo aircraftBo);

    /**
     * 批量删除机型机号
     *
     * @param ids 需要删除的机型机号主键集合
     * @return 结果:true 删除成功，false 删除失败
     */
    boolean deleteByIds(Long[] ids);

    /**
     * 异步导入
     *
     * @param file          导入的文件
     * @param updateSupport 是否覆盖
     * @param user          用户上下文信息
     */
    @Async
    void asyncImportData(MultipartFile file, boolean updateSupport, LoginUser user);

    /**
     * asyncExport 异步导出
     *
     * @param listVo    数据列表
     * @param sheetName 文件名称
     * @param user      上下文
     */
    @Async
    void asyncExport(List<AircraftVo> listVo, String sheetName, LoginUser user);

}
