package org.eco.als.service;

import org.eco.als.domain.AlsFaultCase;
import org.eco.als.domain.bo.AlsFaultCaseBo;
import org.eco.als.domain.vo.AlsFaultCaseVo;
import org.eco.common.core.core.domain.model.LoginUser;
import org.eco.common.core.core.page.PageResult;
import org.eco.common.orm.core.service.IBaseService;
import org.springframework.scheduling.annotation.Async;
import org.springframework.web.multipart.MultipartFile;

import java.util.List;

/**
 * 故障案例Service接口
 *
 * @author wgk
 * @date 2024-07-18
 */
public interface IAlsFaultCaseService extends IBaseService<AlsFaultCase> {
    /**
     * 查询故障案例
     *
     * @param id 故障案例主键
     * @return 故障案例
     */
    AlsFaultCaseVo selectById(Long id);

    /**
     * 查询故障案例列表
     *
     * @param alsFaultCaseBo 故障案例Bo
     * @return 故障案例集合
     */
    List<AlsFaultCaseVo> selectList(AlsFaultCaseBo alsFaultCaseBo);

    /**
     * 分页查询故障案例列表
     *
     * @param alsFaultCaseBo 故障案例Bo
     * @return 分页故障案例集合
     */
    PageResult<AlsFaultCaseVo> selectPage(AlsFaultCaseBo alsFaultCaseBo);

    /**
     * 新增故障案例
     *
     * @param alsFaultCaseBo 故障案例Bo
     * @return 结果:true 操作成功，false 操作失败
     */
    boolean insert(AlsFaultCaseBo alsFaultCaseBo);

    /**
     * 新增故障案例，前台提供主键值，一般用于导入的场合
     *
     * @param alsFaultCaseBo 故障案例Bo
     * @return 结果:true 操作成功，false 操作失败
     */
    boolean insertWithPk(AlsFaultCaseBo alsFaultCaseBo);

    /**
     * 修改故障案例
     *
     * @param alsFaultCaseBo 故障案例Bo
     * @return 结果:true 更新成功，false 更新失败
     */
    boolean update(AlsFaultCaseBo alsFaultCaseBo);

    /**
     * 批量删除故障案例
     *
     * @param ids 需要删除的故障案例主键集合
     * @return 结果:true 删除成功，false 删除失败
     */
    boolean deleteByIds(Long[] ids);

    /**
     * 异步导入
     *
     * @param file          导入的文件
     * @param updateSupport 是否覆盖
     * @param user          用户上下文信息
     */
    @Async
    void asyncImportData(MultipartFile file, boolean updateSupport, LoginUser user);

    /**
     * asyncExport 异步导出
     *
     * @param listVo    数据列表
     * @param sheetName 文件名称
     * @param user      上下文
     */
    @Async
    void asyncExport(List<AlsFaultCaseVo> listVo, String sheetName, LoginUser user);

}
